@@ -35,7 +35,8 @@ setClass("CuffDist",
 #CuffSet Class is a 'pointer' container to a group of CuffData elements in a cufflinks dataset
 setClass("CuffSet",
 		representation(DB = "SQLiteConnection",
-						runInfo = "data.frame",
+						#runInfo = "data.frame",
+						#varModel = "data.frame",
 						phenoData = "data.frame",
 						conditions = "data.frame",
 						genes = "CuffData",
